#version 120
#extension GL_EXT_gpu_shader3 : enable

uniform int lightNumber;
uniform int lightRecieve[7];
uniform int ensemble;

varying float diffuseTotal;
varying float specularTotal;

varying vec3 position;

//##FUNC_SPOT_EFFECT##

void main(void)
{
    gl_TexCoord[0] = gl_TextureMatrix[0] * gl_MultiTexCoord0;
    
    vec3 position_vertex = vec3(gl_ModelViewMatrix * gl_Vertex);
    vec3 normal = normalize(gl_NormalMatrix * gl_Normal);
    gl_FrontColor = vec4(0.0, 0.0, 0.0, 0.0);

    diffuseTotal = 0.0;
    specularTotal = 0.0;
    
    vec3 viewVec = - normalize(position_vertex);
    
    for (int i = 0; i < lightNumber; i++){
	if (lightRecieve[i] == 0) continue;

	vec3 lightVec = gl_LightSource[i].position.xyz - position_vertex * gl_LightSource[i].position[3];
	
	float dis = length(lightVec);
	
	//float attenuation = 1.0;
	
	lightVec = normalize(lightVec);
	
	//gl_FrontColor += gl_FrontLightProduct[i].ambient;

	float diffuse = dot(lightVec, normal);	
	if (diffuse > 0.0){
	    float spotAngleCos = dot(normalize(gl_LightSource[i].spotDirection),
				 -lightVec);
	    float lightFactor = GetSpotEffect(i, spotAngleCos);
	    
	    lightFactor /= (gl_LightSource[0].constantAttenuation +
			    gl_LightSource[0].linearAttenuation * dis +
			    gl_LightSource[0].quadraticAttenuation * dis * dis);

	    vec3 reflectVec = reflect(-lightVec, normal);
	    float specular = pow(max(dot(viewVec, reflectVec), 0.0), 
				 gl_FrontMaterial.shininess);
	    diffuseTotal += diffuse * gl_LightSource[i].diffuse.r * lightFactor;
	    specularTotal += specular * gl_LightSource[i].diffuse.r;
	}
    }
     
    position = vec3(gl_ModelViewMatrix * gl_Vertex);

    gl_Position = ftransform();
}
